# pacotepypi

**pacotepypi** é um simples pacote para exibir números de 1 a 9 em Python.

## Dependências
**Python 3.6** ou posterior

Pacote **numpy**


## Começando o uso
Você vai precisar instalar o pacote **pacotepypi**, para isso basta executar:
```
pip install pacotepypi
```

## Função

* `exibir ()` - Mostra números de 1 a 9